#! -*- coding: utf-8 -*-
import pika


class RabbitMQ(object):

    def __init__(self, host, port, virtual_host, user, password):
        credentials = pika.PlainCredentials(user, password)
        parameters = pika.ConnectionParameters(host=host, port=port, virtual_host=virtual_host, credentials=credentials)
        self.connection = pika.BlockingConnection(parameters)

    def start_mq(self, queue):
        channel = self.connection.channel()
        channel.queue_declare(queue=queue)

        channel.basic_consume(queue=queue, on_message_callback=self.callback, auto_ack=True)

        print('[django-rabbitmq] Waiting for messages. To exit press CTRL+C')
        channel.start_consuming()

    @staticmethod
    def callback(ch, method, properties, body):
        print("[django-rabbitmq] Received %r" % body)




from django.apps import AppConfig
from django.conf import settings
from threading import Thread


class DjangoMqConfig(AppConfig):
    name = 'django_rabbitmq'

    def ready(self):
        thr = Thread(name='mq_thread', target=self.run_mq)
        thr.daemon = True
        thr.start()

    def run_mq(self):
        mq_settings = settings.RABBITMQ.get('default')
        from .mq import RabbitMQ

        mq = RabbitMQ(
            mq_settings.get('HOST'),
            mq_settings.get('PORT'),
            mq_settings.get('VIRTUAL_HOST'),
            mq_settings.get('USER'),
            mq_settings.get('PASSWORD'),
        )

        mq.start_mq(mq_settings.get('QUEUE'))
